@@ -30,8 +30,7 @@
 #include <glib.h>
 #include <glib-object.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
 #include "burn.h"
@@ -59,7 +58,6 @@ GtkWidget *brasero_burn_dialog_new (void);
 
 gboolean
 brasero_burn_dialog_run (BraseroBurnDialog *dialog,
-			 BraseroBurnSession *session,
-			 gboolean *destroy);
+			 BraseroBurnSession *session);
 
 #endif				/* BURN_DIALOG_H */
