@@ -34,6 +34,7 @@
 
 #include "brasero-file-node.h"
 #include "brasero-utils.h"
+#include "brasero-io.h"
 
 BraseroFileNode *
 brasero_file_node_root_new (void)
@@ -455,6 +456,9 @@ brasero_file_node_nth_child (BraseroFileNode *parent,
 	BraseroFileNode *peers;
 	guint pos;
 
+	if (!parent)
+		return NULL;
+
 	peers = BRASERO_FILE_NODE_CHILDREN (parent);
 	for (pos = 0; pos < nth && peers; pos ++)
 		peers = peers->next;
@@ -468,6 +472,9 @@ brasero_file_node_get_n_children (const BraseroFileNode *node)
 	BraseroFileNode *children;
 	guint num = 0;
 
+	if (!node)
+		return 0;
+
 	for (children = BRASERO_FILE_NODE_CHILDREN (node); children; children = children->next)
 		num ++;
 
@@ -481,6 +488,9 @@ brasero_file_node_get_pos_as_child (BraseroFileNode *node)
 	BraseroFileNode *peers;
 	guint pos = 0;
 
+	if (!node)
+		return 0;
+
 	parent = node->parent;
 	for (peers = BRASERO_FILE_NODE_CHILDREN (parent); peers; peers = peers->next) {
 		if (peers == node)
@@ -683,15 +693,16 @@ brasero_file_node_add (BraseroFileNode *parent,
 		       BraseroFileNode *node,
 		       GCompareFunc sort_func)
 {
+	BraseroFileTreeStats *stats;
+	guint depth = 0;
+
 	parent->union2.children = brasero_file_node_insert (BRASERO_FILE_NODE_CHILDREN (parent),
 							    node,
 							    sort_func,
 							    NULL);
-
 	node->parent = parent;
 	if (!node->is_imported) {
-		guint depth = 0;
-
+		/* NOTE: parent will be changed afterwards !!! */
 		if (!node->is_grafted) {
 			/* propagate the size change*/
 			for (; parent && !parent->is_root; parent = parent->parent) {
@@ -700,10 +711,19 @@ brasero_file_node_add (BraseroFileNode *parent,
 					break;
 			}
 		}
-
-		if (depth > 6)
-			node->is_deep = TRUE;
 	}
+
+	/* even imported should be included */
+	stats = brasero_file_node_get_tree_stats (node->parent, &depth);
+	if (node->is_file) {
+		if (depth < 6)
+			return;
+	}
+	else if (depth < 5)
+		return;
+
+	stats->num_deep ++;
+	node->is_deep = TRUE;
 }
 
 void
@@ -838,7 +858,7 @@ brasero_file_node_new_from_info (GFileInfo *info,
 }
 
 BraseroFileNode *
-brasero_file_node_new_imported_session_file (BraseroVolFile *file,
+brasero_file_node_new_imported_session_file (GFileInfo *info,
 					     BraseroFileNode *parent,
 					     GCompareFunc sort_func)
 {
@@ -846,12 +866,16 @@ brasero_file_node_new_imported_session_file (BraseroVolFile *file,
 
 	/* Create the node information */
 	node = g_new0 (BraseroFileNode, 1);
-	node->union1.name = g_strdup (BRASERO_VOLUME_FILE_NAME (file));
-	node->is_file = (file->isdir == FALSE);
+	node->union1.name = g_strdup (g_file_info_get_name (info));
+	node->is_file = (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY);
 	node->is_imported = TRUE;
 
-	if (node->is_file)
-		node->union3.sectors = BRASERO_SIZE_TO_SECTORS (BRASERO_VOLUME_FILE_SIZE (file), 2048);
+	if (!node->is_file) {
+		node->is_fake = TRUE;
+		node->union3.imported_address = g_file_info_get_attribute_int64 (info, BRASERO_IO_DIR_CONTENTS_ADDR);
+	}
+	else
+		node->union3.sectors = BRASERO_SIZE_TO_SECTORS (g_file_info_get_size (info), 2048);
 
 	/* Add it (we must add a graft) */
 	brasero_file_node_add (parent, node, sort_func);
@@ -946,14 +970,11 @@ void
 brasero_file_node_move_from (BraseroFileNode *node,
 			     BraseroFileTreeStats *stats)
 {
-	gboolean was_deep;
-
 	/* NOTE: for the time being no backend supports moving imported files */
 	if (node->is_imported)
 		return;
 
-	was_deep = (brasero_file_node_get_depth (node) > 6);
-	if (was_deep)
+	if (node->is_deep)
 		stats->num_deep --;
 
 	brasero_file_node_unlink (node);
@@ -965,7 +986,7 @@ brasero_file_node_move_to (BraseroFileNode *node,
 			   GCompareFunc sort_func)
 {
 	BraseroFileTreeStats *stats;
-	guint depth;
+	guint depth = 0;
 
 	/* NOTE: for the time being no backend supports moving imported files */
 	if (node->is_imported)
@@ -991,11 +1012,16 @@ brasero_file_node_move_to (BraseroFileNode *node,
 
 	/* NOTE: here stats about the tree can change if the parent has a depth
 	 * > 6 and if previous didn't. Other stats remains unmodified. */
-	stats = brasero_file_node_get_tree_stats (parent, &depth);
-	if (!depth > 6) {
-		stats->num_deep ++;
-		node->is_deep = TRUE;
+	stats = brasero_file_node_get_tree_stats (node->parent, &depth);
+	if (node->is_file) {
+		if (depth < 6)
+			return;
 	}
+	else if (depth < 5)
+		return;
+
+	stats->num_deep ++;
+	node->is_deep = TRUE;
 }
 
 static void
