@@ -33,30 +33,7 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtktoggleaction.h>
-#include <gtk/gtkradioaction.h>
-#include <gtk/gtkaction.h>
-
-#include <gtk/gtkstock.h>
-
-#include <gtk/gtkbox.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkvpaned.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkhseparator.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
+#include <gtk/gtk.h>
 
 #include <gconf/gconf-client.h>
 
@@ -122,13 +99,12 @@ struct BraseroLayoutPrivate {
 static GObjectClass *parent_class = NULL;
 
 #define BRASERO_LAYOUT_PREVIEW_ID	"Viewer"
-#define BRASERO_LAYOUT_PREVIEW_NAME	N_("Preview")
 #define BRASERO_LAYOUT_PREVIEW_MENU	N_("P_review")
 #define BRASERO_LAYOUT_PREVIEW_TOOLTIP	N_("Display video, audio and image preview")
 #define BRASERO_LAYOUT_PREVIEW_ICON	GTK_STOCK_FILE
 
 #define BRASERO_LAYOUT_NONE_ID		"EmptyView"
-#define BRASERO_LAYOUT_NONE_MENU	N_("_Show side panel")
+#define BRASERO_LAYOUT_NONE_MENU	N_("_Show Side Panel")
 #define BRASERO_LAYOUT_NONE_TOOLTIP	N_("Show a side pane along the project")
 #define BRASERO_LAYOUT_NONE_ICON	NULL
 
@@ -571,7 +547,6 @@ brasero_layout_item_set_active (BraseroLayout *layout,
 			return;
 		}
 	} while (gtk_tree_model_iter_next (model, &iter));
-
 }
 
 static void
@@ -742,7 +717,6 @@ brasero_layout_add_source (BraseroLayout *layout,
 			   GtkWidget *source,
 			   const gchar *id,
 			   const gchar *subtitle,
-			   const gchar *tooltip,
 			   const gchar *icon_name,
 			   BraseroLayoutType types)
 {
@@ -787,6 +761,8 @@ brasero_layout_combo_changed_cb (GtkComboBox *combo,
 	BraseroLayoutObject *source;
 	BraseroLayoutItem *item;
 	GtkTreeModel *model;
+	gboolean is_visible;
+	GtkAction *action;
 	GtkTreeIter iter;
 
 	model = gtk_combo_box_get_model (combo);
@@ -797,6 +773,12 @@ brasero_layout_combo_changed_cb (GtkComboBox *combo,
 			    ITEM_COL, &item,
 			    -1);
 
+	/* Make sure there is a displayed sidepane before setting the source for
+	 * project. It can happen that when we're changing of project type this
+	 * is called. */
+	action = gtk_action_group_get_action (layout->priv->action_group, BRASERO_LAYOUT_NONE_ID);
+	is_visible = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+
 	if (layout->priv->active_item)
 		gtk_widget_hide (layout->priv->active_item->widget);
 
@@ -811,6 +793,9 @@ brasero_layout_combo_changed_cb (GtkComboBox *combo,
 		BRASERO_BURN_LOG ("Item is not an URI container");
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project), NULL);
 	}
+	else if (!is_visible) {
+		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project), NULL);
+	}
 	else {
 		brasero_uri_container_uri_selected (BRASERO_URI_CONTAINER (source));
 		brasero_project_set_source (BRASERO_PROJECT (layout->priv->project),
