@@ -329,15 +329,14 @@ brasero_medium_properties_image_extension_ask (BraseroMediumProperties *self)
 					 _("Do you really want to keep the current extension for the disc image name?"));
 
 		
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Image Extension"));
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("If you choose to keep it programs may not be able to recognize the file type properly."));
+						  _("If you choose to keep it, programs may not be able to recognize the file type properly."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("_Don't change extension"),
+			       _("_Keep Current Extension"),
 			       GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
-			       _("Change _extension"),
+			       _("Change _Extension"),
 			       GTK_RESPONSE_YES);
 
 	answer = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -567,7 +566,7 @@ brasero_medium_properties_valid_session (BraseroSessionCfg *session,
 
 	/* make sure the current displayed path is valid */
 	if (brasero_burn_session_is_dest_file (priv->session))
-		brasero_medium_properties_update_image_output (self, brasero_session_cfg_get_error (session) == BRASERO_SESSION_VALID);
+		brasero_medium_properties_update_image_output (self, BRASERO_SESSION_IS_VALID (brasero_session_cfg_get_error (session)));
 }
 
 static void
@@ -579,7 +578,7 @@ brasero_medium_properties_init (BraseroMediumProperties *object)
 
 	priv->caps = brasero_burn_caps_get_default ();
 
-	gtk_widget_set_tooltip_text (GTK_WIDGET (object), _("Configure some options for the recording"));
+	gtk_widget_set_tooltip_text (GTK_WIDGET (object), _("Configure recording options"));
 
 	priv->default_ext = TRUE;
 	priv->default_path = TRUE;
