@@ -134,16 +134,28 @@ brasero_medium_selection_get_medium_string (BraseroMediumSelection *self,
 				      NULL);
 
 	/* format the size */
-	if (media & BRASERO_MEDIUM_HAS_DATA)
+	if (media & BRASERO_MEDIUM_HAS_DATA) {
 		size_string = g_format_size_for_display (size);
-	else
+		/* NOTE for translators: the first %s is the medium name, the
+		 * second %s is the space (kio, gio) used by data on the disc.
+		 */
+		label = g_strdup_printf (_("%s: %s"),
+					 medium_name,
+					 size_string);
+	}
+	else {
 		size_string = brasero_utils_get_time_string_from_size (size,
 								       TRUE,
 								       TRUE);
+		/* NOTE for translators: the first %s is the medium name, the
+		 * second %s is the space (time) used by data on the disc.
+		 * I really don't know if I should set this string as
+		 * translatable. */
+		label = g_strdup_printf (_("%s: %s"),
+					 medium_name,
+					 size_string);
+	}
 
-	/* NOTE for translators: the first %s is the medium name, the second %s
-	 * is the space used by data on the disc. */
-	label = g_strdup_printf (_("%s: %s of data"), medium_name, size_string);
 	g_free (medium_name);
 	g_free (size_string);
 
@@ -155,7 +167,9 @@ brasero_medium_selection_update_media_string (BraseroMediumSelection *self)
 {
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+	gboolean valid;
 
+	valid = FALSE;
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 		return;
@@ -179,7 +193,6 @@ brasero_medium_selection_update_media_string (BraseroMediumSelection *self)
 		g_object_unref (medium);
 		g_free (label);
 	} while (gtk_tree_model_iter_next (model, &iter));
-
 }
 
 static void
@@ -286,6 +299,47 @@ brasero_medium_selection_get_active_drive (BraseroMediumSelection *self)
 	return drive;
 }
 
+static void
+brasero_medium_selection_update_no_disc_entry (BraseroMediumSelection *self,
+					       GtkTreeModel *model,
+					       GtkTreeIter *iter)
+{
+	BraseroMediumMonitor *monitor;
+
+	monitor = brasero_medium_monitor_get_default ();
+	if (brasero_medium_monitor_is_probing (monitor))
+		gtk_list_store_set (GTK_LIST_STORE (model), iter,
+				    NAME_COL, _("Searching for available discs"),
+				    ICON_COL, "image-loading",
+				    -1);
+	else
+		gtk_list_store_set (GTK_LIST_STORE (model), iter,
+				    NAME_COL, _("No available disc"),
+				    ICON_COL, "drive-optical",
+				    -1);
+	g_object_unref (monitor);
+
+	gtk_widget_set_sensitive (GTK_WIDGET (self), FALSE);
+	gtk_combo_box_set_active_iter (GTK_COMBO_BOX (self), iter);
+}
+
+static void
+brasero_medium_selection_add_no_disc_entry (BraseroMediumSelection *self)
+{
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+	BraseroMediumSelectionPrivate *priv;
+
+	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
+
+	/* Nothing's available. Say it. Two cases here, either we're
+	 * still probing drives or there isn't actually any available
+	 * medium. */
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
+	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+	brasero_medium_selection_update_no_disc_entry (self, model, &iter);
+}
+
 void
 brasero_medium_selection_show_type (BraseroMediumSelection *self,
 				    BraseroMediaType type)
@@ -329,13 +383,14 @@ brasero_medium_selection_show_type (BraseroMediumSelection *self,
 			if (!node) {
 				if (gtk_list_store_remove (GTK_LIST_STORE (model), &iter)) {
 					g_signal_emit (self,
-						       brasero_medium_selection_signals [ADDED_SIGNAL],
+						       brasero_medium_selection_signals [REMOVED_SIGNAL],
 						       0);
 					continue;
 				}
 
+				/* no more iter in the tree  get out */
 				g_signal_emit (self,
-					       brasero_medium_selection_signals [ADDED_SIGNAL],
+					       brasero_medium_selection_signals [REMOVED_SIGNAL],
 					       0);
 				break;
 			}
@@ -373,16 +428,11 @@ brasero_medium_selection_show_type (BraseroMediumSelection *self,
 	}
 
 	if (!gtk_tree_model_get_iter_first (model, &iter)) {
-		/* Nothing's available =(. Say it. */
-		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    NAME_COL, _("No available medium"),
-				    -1),
-
-		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (self), &iter);
+		brasero_medium_selection_add_no_disc_entry (self);
 		return;
 	}
 
+	gtk_widget_set_sensitive (GTK_WIDGET (self), TRUE);
 	if (gtk_combo_box_get_active (GTK_COMBO_BOX (self)) == -1)
 		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (self), &iter);
 }
@@ -390,13 +440,30 @@ brasero_medium_selection_show_type (BraseroMediumSelection *self,
 guint
 brasero_medium_selection_get_drive_num (BraseroMediumSelection *self)
 {
-	BraseroMediumSelectionPrivate *priv;
 	GtkTreeModel *model;
-
-	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
+	GtkTreeIter iter;
+	int num = 0;
 
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
-	return gtk_tree_model_iter_n_children (model, NULL);
+	if (!gtk_tree_model_get_iter_first (model, &iter))
+		return 0;
+
+	do {
+		BraseroMedium *medium;
+
+		medium = NULL;
+		gtk_tree_model_get (model, &iter,
+				    MEDIUM_COL, &medium,
+				    -1);
+		if (!medium)
+			continue;
+
+		g_object_unref (medium);
+		num ++;
+
+	} while (gtk_tree_model_iter_next (model, &iter));
+
+	return num;
 }
 
 static void
@@ -433,11 +500,27 @@ brasero_medium_selection_medium_added_cb (BraseroMediumMonitor *monitor,
 			add = TRUE;
 	}
 
-	if (!add)
-		return;
-
 	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
 
+	if (!add) {
+		/* Try to get the first iter (it shouldn't fail) */
+		if (!gtk_tree_model_get_iter_first (model, &iter)) {
+			brasero_medium_selection_add_no_disc_entry (self);
+			return;
+		}
+
+		/* See if that's a real medium or not; if so, return. */
+		medium = NULL;
+		gtk_tree_model_get (model, &iter,
+				    MEDIUM_COL, &medium,
+				    -1);
+		if (medium)
+			return;
+
+		brasero_medium_selection_update_no_disc_entry (self, model, &iter);
+		return;
+	}
+
 	/* remove warning message */
 	if (gtk_tree_model_get_iter_first (model, &iter)) {
 		BraseroMedium *tmp;
@@ -461,6 +544,7 @@ brasero_medium_selection_medium_added_cb (BraseroMediumMonitor *monitor,
 			    -1);
 	g_free (medium_name);
 
+	gtk_widget_set_sensitive (GTK_WIDGET (self), TRUE);
 	if (gtk_combo_box_get_active (GTK_COMBO_BOX (self)) == -1)
 		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (self), &iter);
 
@@ -504,13 +588,7 @@ brasero_medium_selection_medium_removed_cb (BraseroMediumMonitor *monitor,
 	} while (gtk_tree_model_iter_next (model, &iter));
 
 	if (!gtk_tree_model_get_iter_first (model, &iter)) {
-		/* Nothing's available any more =(. Say it. */
-		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    NAME_COL, _("No available medium"),
-				    -1),
-
-		gtk_combo_box_set_active_iter (GTK_COMBO_BOX (self), &iter);
+		brasero_medium_selection_add_no_disc_entry (self);
 		return;
 	}
 
