@@ -39,22 +39,7 @@
 
 #include <gio/gio.h>
 
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtktreeviewcolumn.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkfilechooserdialog.h>
-#include <gtk/gtkselection.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
 #ifdef BUILD_SEARCH
 #include <beagle/beagle.h>
@@ -62,6 +47,7 @@
 
 #include <totem-pl-parser.h>
 
+#include "brasero-app.h"
 #include "brasero-playlist.h"
 #include "brasero-utils.h"
 #include "brasero-metadata.h"
@@ -326,7 +312,7 @@ brasero_playlist_init (BraseroPlaylist *obj)
 	gtk_tree_view_column_set_expand (column, TRUE);
 
 	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes (_("Number of songs"),
+	column = gtk_tree_view_column_new_with_attributes (_("Number of Songs"),
 							   renderer, "text",
 							   BRASERO_PLAYLIST_NB_SONGS_COL,
 							   NULL);
@@ -554,9 +540,9 @@ brasero_playlist_start_beagle_search (BraseroPlaylist *playlist)
 	}
 	else {
 		/* we will retry in 10 seconds */
-		playlist->priv->id = g_timeout_add (10000,
-					       (GSourceFunc) brasero_playlist_try_again,
-					       playlist);
+		playlist->priv->id = g_timeout_add_seconds (10,
+							    (GSourceFunc) brasero_playlist_try_again,
+							    playlist);
 	}
 }
 
@@ -814,7 +800,7 @@ static void
 brasero_playlist_dialog_error (BraseroPlaylist *playlist, const gchar *uri)
 {
 	gchar *name;
-	GtkWidget *dialog;
+	gchar *primary;
 	GtkWidget *toplevel;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (playlist));
@@ -824,22 +810,14 @@ brasero_playlist_dialog_error (BraseroPlaylist *playlist, const gchar *uri)
 	}
 
 	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT|
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
-					 _("Error parsing playlist \"%s\":"),
-					 name);
+
+	primary = g_strdup_printf (_("Error parsing playlist \"%s\"."), name);
+	brasero_app_alert (BRASERO_APP (toplevel),
+			   primary,
+			   _("An unknown error occured"),
+			   GTK_MESSAGE_ERROR);
+	g_free (primary);
 	g_free (name);
-
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("an unknown error occured."));
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Playlist Loading Error"));
-
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -940,8 +918,8 @@ brasero_playlist_parse_result (GObject *object,
 	/* update the playlist information */
 	num = gtk_tree_model_iter_n_children (model, &parent);
 	if (!num)
-		num_string = g_strdup (_("empty"));
-	else
+		num_string = g_strdup (_("Empty"));
+	else	/* Translators: %d is the number of songs */
 		num_string = g_strdup_printf (ngettext ("%d song", "%d songs", num), num);
 
 	/* get total length in time of the playlist */
@@ -979,7 +957,7 @@ brasero_playlist_insert (BraseroPlaylist *playlist, const gchar *uri)
 	gtk_tree_store_set (GTK_TREE_STORE (model), &parent,
 			    BRASERO_PLAYLIST_DISPLAY_COL, name,
 			    BRASERO_PLAYLIST_URI_COL, uri,
-			    BRASERO_PLAYLIST_NB_SONGS_COL, _("Loading ..."),
+			    BRASERO_PLAYLIST_NB_SONGS_COL, _("(loading ...)"),
 			    -1);
 	g_free (name);
 
