@@ -33,6 +33,7 @@
 #include "eggtreemultidnd.h"
 
 #include "burn-debug.h"
+#include "brasero-app.h"
 #include "brasero-disc.h"
 #include "brasero-io.h"
 #include "brasero-utils.h"
@@ -41,6 +42,7 @@
 #include "brasero-video-tree-model.h"
 #include "brasero-multi-song-props.h"
 #include "brasero-song-properties.h"
+#include "brasero-session-cfg.h"
 
 typedef struct _BraseroVideoDiscPrivate BraseroVideoDiscPrivate;
 struct _BraseroVideoDiscPrivate
@@ -236,21 +238,17 @@ brasero_video_disc_directory_dialog (BraseroVideoProject *project,
 	GtkWidget *toplevel;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 _("Do you want to search for video files inside the directory?"));
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Directory Search"));
+	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+				     _("Do you want to search for video files inside the directory?"),
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Directories can't be added to video disc."));
+						  _("Directories cannot be added to video discs."));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				_("Search directory"), GTK_RESPONSE_OK,
+				_("_Search Directory"), GTK_RESPONSE_OK,
 				NULL);
 
 	gtk_widget_show_all (dialog);
@@ -269,7 +267,8 @@ brasero_video_disc_unreadable_uri_dialog (BraseroVideoProject *project,
 					  const gchar *uri,
 					  BraseroVideoDisc *self)
 {
-	GtkWidget *dialog, *toplevel;
+	GtkWidget *toplevel;
+	gchar *primary;
 	gchar *name;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
@@ -281,22 +280,13 @@ brasero_video_disc_unreadable_uri_dialog (BraseroVideoProject *project,
 	}
 
 	name = g_filename_display_basename (uri);
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT|
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
-					 _("File \"%s\" can't be opened."),
-					 name);
+	primary = g_strdup_printf (_("\"%s\" could not be opened."), name);
+	brasero_app_alert (BRASERO_APP (toplevel),
+			   primary,
+			   error->message,
+			   GTK_MESSAGE_ERROR);
+	g_free (primary);
 	g_free (name);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Unreadable file"));
-
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  error->message);
-
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
 }
 
 static void
@@ -304,7 +294,8 @@ brasero_video_disc_not_video_dialog (BraseroVideoProject *project,
 				     const gchar *uri,
 				     BraseroVideoDisc *self)
 {
-	GtkWidget *dialog, *toplevel;
+	GtkWidget *toplevel;
+	gchar *primary;
 	gchar *name;
 
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
@@ -314,22 +305,13 @@ brasero_video_disc_not_video_dialog (BraseroVideoProject *project,
 	}
 
 	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT|
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_ERROR,
-					 GTK_BUTTONS_CLOSE,
-					 _("\"%s\" does not have a suitable type for video projects."),
-					 name);
+	primary = g_strdup_printf (_("\"%s\" does not have a suitable type for video projects."), name);
+	brasero_app_alert (BRASERO_APP (toplevel),
+			   primary,
+			   _("Please only add files with video contents"),
+			   GTK_MESSAGE_ERROR);
+	g_free (primary);
 	g_free (name);
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Unhandled file"));
-
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Please only add files with video contents."));
-
-	gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (dialog);
 }
 
 static BraseroDiscResult
@@ -362,6 +344,7 @@ brasero_video_disc_add_uri_real (BraseroVideoDisc *self,
 
 	file = brasero_video_project_add_uri (project,
 					      uri,
+					      NULL,
 					      sibling,
 					      start,
 					      end);
@@ -509,10 +492,10 @@ brasero_video_disc_rename_songs (GtkTreeModel *model,
 	if (!file)
 		return FALSE;
 
-	if (file->name)
-		g_free (file->name);
+	if (file->info->title)
+		g_free (file->info->title);
 
-	file->name = g_strdup (new_name);
+	file->info->title = g_strdup (new_name);
 	return TRUE;
 }
 
@@ -520,8 +503,8 @@ static void
 brasero_video_disc_edit_song_properties_list (BraseroVideoDisc *self,
 					      GList *list)
 {
-	GList *item;
 	gint isrc;
+	GList *item;
 	GList *copy;
 	GtkWidget *props;
 	GtkWidget *toplevel;
@@ -605,8 +588,12 @@ static void
 brasero_video_disc_edit_song_properties_file (BraseroVideoDisc *self,
 					      BraseroVideoFile *file)
 {
+	gint isrc;
 	gint64 end;
 	gint64 start;
+	gchar *title;
+	gchar *artist;
+	gchar *composer;
 	GtkWidget *props;
 	GtkWidget *toplevel;
 	GtkTreeModel *model;
@@ -615,7 +602,6 @@ brasero_video_disc_edit_song_properties_file (BraseroVideoDisc *self,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 
-
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree));
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
 
@@ -643,24 +629,51 @@ brasero_video_disc_edit_song_properties_file (BraseroVideoDisc *self,
 	if (result != GTK_RESPONSE_ACCEPT)
 		goto end;
 
-	brasero_song_info_free (file->info);
-	file->info = g_new0 (BraseroSongInfo, 1);
-
 	brasero_song_props_get_properties (BRASERO_SONG_PROPS (props),
-					   &file->info->artist,
-					   &file->info->title,
-					   &file->info->composer,
-					   &file->info->isrc,
+					   &artist,
+					   &title,
+					   &composer,
+					   &isrc,
 					   &start,
 					   &end,
 					   NULL);
 
+	if (title) {
+		if (file->info->title)
+			g_free (file->info->title);
+
+		file->info->title = title;
+		file->title_set = TRUE;
+	}
+
+	if (artist) {
+		if (file->info->artist)
+			g_free (file->info->artist);
+
+		file->info->artist = artist;
+		file->artist_set = TRUE;
+	}
+
+	if (composer) {
+		if (file->info->composer)
+			g_free (file->info->composer);
+
+		file->info->composer = composer;
+		file->composer_set = TRUE;
+	}
+
+	if (isrc) {
+		file->info->isrc = isrc;
+		file->isrc_set = TRUE;
+	}
+
 	brasero_video_project_resize_file (BRASERO_VIDEO_PROJECT (model), file, start, end);
 
 end:
 
 	gtk_widget_destroy (props);
 }
+
 static void
 brasero_video_disc_edit_information_cb (GtkAction *action,
 					BraseroVideoDisc *self)
@@ -1312,25 +1325,40 @@ brasero_video_disc_set_property (GObject * object,
 }
 
 static BraseroDiscResult
-brasero_video_disc_get_status (BraseroDisc *self)
+brasero_video_disc_get_status (BraseroDisc *self,
+			       gint *remaining,
+			       gchar **current_task)
 {
 	BraseroVideoProject *project;
 	BraseroVideoDiscPrivate *priv;
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 	project = BRASERO_VIDEO_PROJECT (gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree)));
-	return brasero_video_project_get_status (project);
+	return brasero_video_project_get_status (project, remaining, current_task);
 }
 
 BraseroDiscResult
 brasero_video_disc_set_session_param (BraseroDisc *self,
 				      BraseroBurnSession *session)
 {
+	BraseroVideoDiscPrivate *priv;
 	BraseroTrackType type;
+	GtkTreeModel *model;
+	GValue *value;
+
+	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 
 	type.type = BRASERO_TRACK_TYPE_AUDIO;
 	type.subtype.audio_format = BRASERO_AUDIO_FORMAT_UNDEFINED|BRASERO_VIDEO_FORMAT_UNDEFINED;
 	brasero_burn_session_set_input_type (session, &type);
+
+	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree));
+	value = g_new0 (GValue, 1);
+	g_value_init (value, G_TYPE_INT64);
+	g_value_set_int64 (value, brasero_video_project_get_size (BRASERO_VIDEO_PROJECT (model)));
+	brasero_burn_session_tag_add (session,
+				      BRASERO_AUDIO_TRACK_SIZE_TAG,
+				      value);
 	return BRASERO_BURN_OK;
 }
 
@@ -1344,7 +1372,7 @@ brasero_video_disc_set_session_contents (BraseroDisc *self,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 	project = BRASERO_VIDEO_PROJECT (gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree)));
-	tracks = brasero_video_project_get_contents (project);
+	tracks = brasero_video_project_get_contents (project, FALSE);
 
 	if (!tracks)
 		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
@@ -1377,7 +1405,7 @@ brasero_video_disc_get_track (BraseroDisc *disc,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (disc);
 	project = BRASERO_VIDEO_PROJECT (gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree)));
-	tracks = brasero_video_project_get_contents (project);
+	tracks = brasero_video_project_get_contents (project, TRUE);
 
 	for (iter = tracks; iter; iter = iter->next) {
 		BraseroDiscSong *song;
@@ -1386,10 +1414,11 @@ brasero_video_disc_get_track (BraseroDisc *disc,
 		track = iter->data;
 
 		song = g_new0 (BraseroDiscSong, 1);
-		song->uri = brasero_track_get_audio_source (track, TRUE);;
+		song->uri = brasero_track_get_audio_source (track, TRUE);
 		song->start = brasero_track_get_audio_start (track);
 		song->end = brasero_track_get_audio_end (track);
 		song->info = brasero_song_info_copy (brasero_track_get_audio_info (track));
+
 		disc_track->contents.tracks = g_slist_append (disc_track->contents.tracks, song);
 	}
 
@@ -1423,6 +1452,7 @@ brasero_video_disc_load_track (BraseroDisc *disc,
 
 		brasero_video_project_add_uri (BRASERO_VIDEO_PROJECT (project),
 					       song->uri,
+					       song->info,
 					       NULL,
 					       song->start,
 					       song->end);
