@@ -74,12 +74,12 @@ brasero_burn_action_to_string (BraseroBurnAction action)
 							N_("Creating checksum"),
 							N_("Copying disc"),
 							N_("Copying file"),
-							N_("Analysing audio information"),
+							N_("Analysing audio files"),
 							N_("Transcoding song"),
 							N_("Preparing to write"),
 							N_("Writing leadin"),
 							N_("Writing CD-TEXT information"),
-							N_("Fixating"),
+							N_("Finalising"),
 							N_("Writing leadout"),
 						        N_("Starting to record"),
 							N_("Success") };
