@@ -307,10 +307,12 @@ brasero_job_allow_deactivation (BraseroJob *self,
 	return BRASERO_BURN_NOT_RUNNING;
 
 error:
+
 	g_set_error (error,
 		     BRASERO_BURN_ERR,
-		     BRASERO_BURN_ERROR_GENERAL,
-		     _("plugin %s did not want to work. Try to deactivate it"),
+		     BRASERO_BURN_ERROR_PLUGIN_MISBEHAVIOR,
+		     /* Translators: %s is the plugin name */
+		     _("\"%s\" did not behave properly"),
 		     G_OBJECT_TYPE_NAME (self));
 	return BRASERO_BURN_ERR;
 }
@@ -402,13 +404,13 @@ brasero_job_check_output_disc_space (BraseroJob *self,
 	/* this is not really an error, we'll probably ask the 
 	 * user to load a new disc */
 	if (output_blocks > media_blocks) {
-		BRASERO_BURN_LOG ("Insufficient space on media %lli/%lli",
+		BRASERO_BURN_LOG ("Insufficient space on disc %lli/%lli",
 				  media_blocks,
 				  output_blocks);
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
-			     BRASERO_BURN_ERROR_MEDIA_SPACE,
-			     _("Insufficient space on media (%lli available for %lli)"),
+			     BRASERO_BURN_ERROR_MEDIUM_SPACE,
+			     _("Not enough space available on the disc (%lli available for %lli)"),
 			     media_blocks,
 			     output_blocks);
 		return BRASERO_BURN_NEED_RELOAD;
@@ -421,9 +423,9 @@ static BraseroBurnResult
 brasero_job_check_output_volume_space (BraseroJob *self,
 				       GError **error)
 {
-	GFile *file;
 	GFileInfo *info;
 	gchar *directory;
+	GFile *file = NULL;
 	struct rlimit limit;
 	guint64 vol_size = 0;
 	gint64 output_size = 0;
@@ -435,7 +437,7 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 
 	priv = BRASERO_JOB_PRIVATE (self);
 
-	/* get the size and filesystem type for the volume first.
+	/* Get the size and filesystem type for the volume first.
 	 * NOTE: since any plugin must output anything LOCALLY, we can then use
 	 * all libc API. */
 	if (!priv->output)
@@ -448,6 +450,29 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 	if (file == NULL)
 		goto error;
 
+	info = g_file_query_info (file,
+				  G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE,
+				  G_FILE_QUERY_INFO_NONE,
+				  NULL,
+				  error);
+	if (!info)
+		goto error;
+
+	/* Check permissions first */
+	if (!g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_ACCESS_CAN_WRITE)) {
+		BRASERO_JOB_LOG (self, "No permissions");
+
+		g_object_unref (info);
+		g_object_unref (file);
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_PERMISSION,
+			     _("You do not have the required permission to write at this location"));
+		return BRASERO_BURN_ERR;
+	}
+	g_object_unref (info);
+
+	/* Now size left */
 	info = g_file_query_filesystem_info (file,
 					     G_FILE_ATTRIBUTE_FILESYSTEM_FREE ","
 					     G_FILE_ATTRIBUTE_FILESYSTEM_TYPE,
@@ -457,8 +482,7 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 		goto error;
 
 	g_object_unref (file);
-
-	brasero_job_get_session_output_size (BRASERO_JOB (self), NULL, &output_size);
+	file = NULL;
 
 	/* Now check the filesystem type: the problem here is that some
 	 * filesystems have a maximum file size limit of 4 GiB and more than
@@ -469,10 +493,11 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 	if (output_size >= 2147483648ULL
 	&&  filesystem
 	&& !strcmp (filesystem, "msdos")) {
+		g_object_unref (info);
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_DISK_SPACE,
-			     _("The filesystem you chose to store the temporary image on cannot hold files with a size over 2 GiB."));
+			     _("The filesystem you chose to store the temporary image on cannot hold files with a size over 2 GiB"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -509,7 +534,7 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_DISK_SPACE,
-			     _("the selected location does not have enough free space to store the disc image (%ld MiB needed)"),
+			     _("The location you chose to store the temporary image on does not have enough free space for the disc image (%ld MiB needed)"),
 			     (unsigned long) output_size / 1048576);
 		return BRASERO_BURN_ERR;
 	}
@@ -522,8 +547,11 @@ error:
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("the size of the volume can't be checked (Unknown error)"));
-	g_object_unref (file);
+			     _("The size of the volume could not be retrieved"));
+
+	if (file)
+		g_object_unref (file);
+
 	return BRASERO_BURN_ERR;
 }
 
@@ -535,6 +563,7 @@ brasero_job_set_output_file (BraseroJob *self,
 	BraseroBurnResult result;
 	BraseroJobPrivate *priv;
 	BraseroBurnFlag flags;
+	gint64 output_size = 0;
 	gchar *image = NULL;
 	gchar *toc = NULL;
 
@@ -542,6 +571,12 @@ brasero_job_set_output_file (BraseroJob *self,
 
 	/* no next job so we need a file pad */
 	session = brasero_task_ctx_get_session (priv->ctx);
+
+	/* If the plugin is not supposed to output anything, then don't test */
+	brasero_job_get_session_output_size (BRASERO_JOB (self), NULL, &output_size);
+	if (!output_size)
+		return BRASERO_BURN_OK;
+
 	flags = brasero_burn_session_get_flags (session);
 	if (priv->type.type == BRASERO_TRACK_TYPE_IMAGE) {
 		BraseroImageFormat format;
@@ -561,8 +596,8 @@ brasero_job_set_output_file (BraseroJob *self,
 			|| (priv->type.subtype.img_format != BRASERO_IMAGE_FORMAT_BIN && !toc)) {
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
-					     BRASERO_BURN_ERROR_GENERAL,
-					     _("no path"));
+					     BRASERO_BURN_ERROR_OUTPUT_NONE,
+					     _("No path was specified for the image output"));
 				return BRASERO_BURN_ERR;
 			}
 
@@ -588,7 +623,7 @@ brasero_job_set_output_file (BraseroJob *self,
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     _("%s already exists"),
+					     _("\"%s\" already exists"),
 					     image);
 				g_free (toc);
 				g_free (image);
@@ -603,7 +638,7 @@ brasero_job_set_output_file (BraseroJob *self,
 					g_set_error (error,
 						     BRASERO_BURN_ERROR,
 						     BRASERO_BURN_ERROR_GENERAL,
-						     _("%s already exists"),
+						     _("\"%s\" already exists"),
 						     toc);
 					g_free (toc);
 					g_free (image);
@@ -729,10 +764,11 @@ brasero_job_item_start (BraseroTaskItem *item,
 		if (pipe (fd)) {
                         int errsv = errno;
 
+			BRASERO_BURN_LOG ("A pipe couldn't be created");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("the pipe couldn't be created (%s)"),
+				     _("An internal error occured (%s)"),
 				     g_strerror (errsv));
 
 			return BRASERO_BURN_ERR;
@@ -760,9 +796,8 @@ brasero_job_item_start (BraseroTaskItem *item,
 		if (priv->linked) {
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("plugin %s did not work properly.\n"
-				       "Try to deactivate it"),
+				     BRASERO_BURN_ERROR_PLUGIN_MISBEHAVIOR,
+				     _("\"%s\" did not behave properly"),
 				     G_OBJECT_TYPE_NAME (self));
 			return BRASERO_BURN_ERR;
 		}
@@ -774,9 +809,8 @@ brasero_job_item_start (BraseroTaskItem *item,
 		if (action != BRASERO_JOB_ACTION_SIZE) {
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("plugin %s didn't work properly (it does not support operation).\n"
-				       "Try to deactivate it"),
+				     BRASERO_BURN_ERROR_PLUGIN_MISBEHAVIOR,
+				     _("\"%s\" did not behave properly"),
 				     G_OBJECT_TYPE_NAME (self));
 			return BRASERO_BURN_ERR;
 		}
@@ -994,8 +1028,9 @@ brasero_job_finished_session (BraseroJob *self)
 		 * only call for a stop on an error. */
 		BRASERO_JOB_LOG (self, "is not a leader");
 		error = g_error_new (BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("a plugin did not behave properly"));
+				     BRASERO_BURN_ERROR_PLUGIN_MISBEHAVIOR,
+				     _("\"%s\" did not behave properly"),
+				     G_OBJECT_TYPE_NAME (self));
 		return brasero_task_ctx_error (priv->ctx,
 					       BRASERO_BURN_ERR,
 					       error);
@@ -1036,7 +1071,7 @@ brasero_job_finished_track (BraseroJob *self)
 
 	priv = BRASERO_JOB_PRIVATE (self);
 
-	BRASERO_JOB_LOG (self, "finished track successfully");
+	BRASERO_JOB_LOG (self, "Finished track successfully");
 
 	/* we first check if it's the first job */
 	if (brasero_job_is_first_active (self)) {
@@ -1083,8 +1118,9 @@ brasero_job_finished_track (BraseroJob *self)
 		 * for a stop on an error. */
 		BRASERO_JOB_LOG (self, "is not a leader");
 		error = g_error_new (BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("a plugin did not behave properly"));
+				     BRASERO_BURN_ERROR_PLUGIN_MISBEHAVIOR,
+				     _("\"%s\" did not behave properly"),
+				     G_OBJECT_TYPE_NAME (self));
 		return brasero_task_ctx_error (priv->ctx, BRASERO_BURN_ERR, error);
 	}
 
@@ -1179,18 +1215,20 @@ brasero_job_set_nonblocking_fd (int fd, GError **error)
 		 * automatically but still offer that possibility. */
 		flags |= O_NONBLOCK;
 		if (fcntl (fd, F_SETFL, flags) == -1) {
+			BRASERO_BURN_LOG ("couldn't set non blocking mode");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("couldn't set non blocking mode"));
+				     _("An internal error occured"));
 			return BRASERO_BURN_ERR;
 		}
 	}
 	else {
+		BRASERO_BURN_LOG ("couldn't get pipe flags");
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("couldn't get pipe flags"));
+			     _("An internal error occured"));
 		return BRASERO_BURN_ERR;
 	}
 
@@ -1645,12 +1683,10 @@ brasero_job_get_tmp_file (BraseroJob *self,
 
 	priv = BRASERO_JOB_PRIVATE (self);
 	session = brasero_task_ctx_get_session (priv->ctx);
-	brasero_burn_session_get_tmp_file (session,
-					   suffix,
-					   output,
-					   error);
-
-	return BRASERO_BURN_OK;
+	return brasero_burn_session_get_tmp_file (session,
+						  suffix,
+						  output,
+						  error);
 }
 
 BraseroBurnResult
