@@ -128,6 +128,9 @@ brasero_song_info_copy (BraseroSongInfo *info)
 {
 	BraseroSongInfo *copy;
 
+	if (!info)
+		return NULL;
+
 	copy = g_new0 (BraseroSongInfo, 1);
 
 	copy->title = g_strdup (info->title);
@@ -612,9 +615,6 @@ brasero_track_set_image_source (BraseroTrack *track,
 	if (track->type.type != BRASERO_TRACK_TYPE_IMAGE)
 		return BRASERO_BURN_NOT_SUPPORTED;
 
-	if (format == BRASERO_IMAGE_FORMAT_NONE)
-		return BRASERO_BURN_NOT_SUPPORTED;
-
 	track->type.subtype.img_format = format;
 
 	image = (BraseroTrackImage *) track;
@@ -1147,7 +1147,10 @@ brasero_track_tag_add (BraseroTrack *track,
 						     g_str_equal,
 						     g_free,
 						     brasero_track_tag_value_free);
-	g_hash_table_insert (track->tags, g_strdup (tag), value);
+	g_hash_table_insert (track->tags,
+			     g_strdup (tag),
+			     value);
+
 	return BRASERO_BURN_OK;
 }
 
