@@ -37,7 +37,7 @@ typedef gboolean (*BraseroVolSrcReadFunc)	(BraseroVolSrc *src,
 						 gchar *buffer,
 						 guint size,
 						 GError **error);
-typedef gboolean (*BraseroVolSrcSeekFunc)	(BraseroVolSrc *src,
+typedef gint64	 (*BraseroVolSrcSeekFunc)	(BraseroVolSrc *src,
 						 guint block,
 						 gint whence,
 						 GError **error);
@@ -61,10 +61,6 @@ BraseroVolSrc *
 brasero_volume_source_open_device_handle (BraseroDeviceHandle *handle,
 					  GError **error);
 BraseroVolSrc *
-brasero_volume_source_open_device_path (const gchar *path,
-					GError **error);
-
-BraseroVolSrc *
 brasero_volume_source_open_file (const gchar *path,
 				 GError **error);
 BraseroVolSrc *
