@@ -78,89 +78,46 @@ static GObjectClass *parent_class = NULL;
 static BraseroBurnResult
 brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 {
-	BraseroWodim *wodim = BRASERO_WODIM (process);
-	BraseroWodimPrivate *priv;
 	BraseroBurnFlag flags;
 
-	priv = BRASERO_WODIM_PRIVATE (wodim);
-	brasero_job_get_flags (BRASERO_JOB (wodim), &flags);
+	brasero_job_get_flags (BRASERO_JOB (process), &flags);
 
-	if (strstr (line, "Cannot open SCSI driver.")) {
+	if (strstr (line, "Cannot open SCSI driver.")
+	||  strstr (line, "Operation not permitted. Cannot send SCSI cmd via ioctl")
+	||  strstr (line, "Cannot open or use SCSI driver")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_PERMISSION,
-						_("You don't seem to have the required permission to use this drive")));
-	}
-	else if (strstr (line, "No disk / Wrong disk!") != NULL) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_MEDIA_NONE,
-						_("There doesn't seem to be a disc in the drive")));
-	}
-	else if (strstr (line, "Input buffer error, aborting") != NULL) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("input buffer error")));
-	}
-	else if (strstr (line, "This means that we are checking recorded media.") != NULL) {
-		/* NOTE: defer the consequence of this error as it is not always
-		 * fatal. So send a warning but don't stop the process. */
-		brasero_process_deferred_error (process,
-						g_error_new (BRASERO_BURN_ERROR,
-							     BRASERO_BURN_ERROR_MEDIA_NOT_WRITABLE,
-							     _("The CD has already been recorded")));
-	}
-	else if (strstr (line, "Cannot blank disk, aborting.") != NULL) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_MEDIA_NOT_REWRITABLE,
-						_("The CD cannot be blanked")));
+						_("You do not have the required permissions to use this drive")));
 	}
 	else if (!(flags & BRASERO_BURN_FLAG_OVERBURN)
 	     &&  strstr (line, "Data may not fit on current disk")) {
 		/* we don't error out if overburn was chosen */
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_MEDIA_SPACE,
-						_("The files selected did not fit on the CD")));
+						BRASERO_BURN_ERROR_MEDIUM_SPACE,
+						_("Not enough space available on the disc")));
 	}
-	else if (strstr (line ,"wodim: A write error occured")) {
+	else if (strstr (line ,"cdrecord: A write error occured")
+	     ||  strstr (line, "Could not write Lead-in")
+	     ||  strstr (line, "Cannot fixate disk")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("a write error occured which was likely due to overburning the disc")));
-	}
-	else if (strstr (line, "Inappropriate audio coding")) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_INCOMPATIBLE_FORMAT,
-						_("All audio files must be stereo, 16-bit digital audio with 44100Hz samples")));
-	}
-	else if (strstr (line, "cannot write medium - incompatible format") != NULL) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_INCOMPATIBLE_FORMAT,
-						_("The image does not seem to be a proper iso9660 file system")));
+						BRASERO_BURN_ERROR_WRITE_MEDIUM,
+						_("An error occured while writing to disc")));
 	}
 	else if (strstr (line, "DMA speed too slow") != NULL) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_SLOW_DMA,
-						_("The system is too slow to write the CD at this speed. Try a lower speed")));
-	}
-	else if (strstr (line, "Operation not permitted. Cannot send SCSI cmd via ioctl")) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_SCSI_IOCTL,
-						_("You don't seem to have the required permission to use this drive")));
+						_("The system is too slow to write the disc at this speed. Try a lower speed")));
 	}
 	else if (strstr (line, "Device or resource busy")) {
 		if (!strstr (line, "retrying in")) {
 			brasero_job_error (BRASERO_JOB (process),
 					   g_error_new (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_BUSY_DRIVE,
-							_("The drive seems to be busy (maybe check you have proper permissions to use it)")));
+							BRASERO_BURN_ERROR_DRIVE_BUSY,
+							_("The drive is busy")));
 		}
 	}
 	else if (strstr (line, "Illegal write mode for this drive")) {
@@ -168,40 +125,71 @@ brasero_wodim_stderr_read (BraseroProcess *process, const gchar *line)
 		 * drive with cdrdao and eject it. Should we ? */
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_BUSY_DRIVE,
-						_("The drive seems to be busy (maybe you should reload the media)")));
+						BRASERO_BURN_ERROR_DRIVE_BUSY,
+						_("The drive is busy")));
 	}
-	else if (strstr (line, "wodim: No such file or directory. Cannot open")) {
+
+	/* REMINDER: these should not be necessary as we checked that already */
+	/**
+	else if (strstr (line, "cannot write medium - incompatible format") != NULL) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("the image file cannot be found")));
+						BRASERO_BURN_ERROR_INPUT_INVALID,
+						_("The image does not seem to be a proper iso9660 file system")));
 	}
-	else if (strstr (line, "Bad file descriptor. read error on input file")
-	     ||  strstr (line, "No tracks specified. Need at least one.")) {
+	else if (strstr (line, "This means that we are checking recorded media.") != NULL) {
+	**/	/* NOTE: defer the consequence of this error as it is not always
+		 * fatal. So send a warning but don't stop the process. */
+	/**	brasero_process_deferred_error (process,
+						g_error_new (BRASERO_BURN_ERROR,
+							     BRASERO_BURN_ERROR_MEDIUM_INVALID,
+							     _("The disc is already burnt")));
+	}
+	else if (strstr (line, "Cannot blank disk, aborting.") != NULL) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("internal error")));
-	}
-	else if (strstr (line, "Could not write Lead-in")) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("the cd information could not be written")));
-	}
-	else if (strstr (line, "Cannot fixate disk")) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("the disc could not be closed")));
+						BRASERO_BURN_ERROR_MEDIUM_INVALID,
+						_("The disc could not be blanked")));
 	}
 	else if (strstr (line, "Bad audio track size")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
 						BRASERO_BURN_ERROR_GENERAL,
-						_("the audio tracks are too short or not a multiple of 2352")));
+						_("The audio tracks are too short or not a multiple of 2352")));
 	}
+	else if (strstr (line, "cdrecord: No such file or directory. Cannot open")
+	     ||  strstr (line, "No tracks specified. Need at least one.")) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new (BRASERO_BURN_ERROR,
+						BRASERO_BURN_ERROR_INPUT,
+						_("The image file cannot be found")));
+	}
+	else if (strstr (line, "Inappropriate audio coding")) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new (BRASERO_BURN_ERROR,
+						BRASERO_BURN_ERROR_INPUT_INVALID,
+						_("All audio files must be stereo, 16-bit digital audio with 44100Hz samples")));
+	}
+	else if (strstr (line, "No disk / Wrong disk!") != NULL) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new (BRASERO_BURN_ERROR,
+						BRASERO_BURN_ERROR_MEDIA_NONE,
+						_("There seems to be no disc in the drive")));
+	}
+
+	**/
+
+	/** For these we'd rather have a message saying "cdrecord failed"
+	 *  as an internal error occured says nothing/even less
+	else if (strstr (line, "Bad file descriptor. read error on input file")
+	     ||  strstr (line, "Input buffer error, aborting")) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new (BRASERO_BURN_ERROR,
+						BRASERO_BURN_ERROR_GENERAL,
+						_("An internal error occured")));
+	}
+
+	**/
 
 	return BRASERO_BURN_OK;
 }
@@ -336,8 +324,8 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_RELOAD_MEDIA,
-						_("The media needs to be reloaded before being recorded")));
+						BRASERO_BURN_ERROR_MEDIUM_NEED_RELOADING,
+						_("The disc needs to be reloaded before being recorded")));
 	}
 	else if (g_str_has_prefix (line, "Fixating...")
 	     ||  g_str_has_prefix (line, "Writing Leadout...")) {
@@ -353,12 +341,8 @@ brasero_wodim_stdout_read (BraseroProcess *process, const gchar *line)
 	     ||  strstr (line, "Blanking entire disk")) {
 
 	}
-	else if (strstr (line, "Use tsize= option in SAO mode to specify track size")) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("internal error")));
-	}
+	/* This should not happen */
+	/* else if (strstr (line, "Use tsize= option in SAO mode to specify track size")) */
 
 	return BRASERO_BURN_OK;
 }
@@ -427,6 +411,16 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 
 	BRASERO_JOB_LOG (wodim, "writing inf (%s)", path);
 
+	/* The problem here is that when writing CD-TEXT from .inf files, wodim
+	 * uses only one charset (and don't let us specify which one) which is
+	 * ISO-8859-1. (NOTE: don't believe the doc claiming it requires ASCII
+	 * and see cdrecord/cdtext.c line 309).
+	 * So we have to convert our UTF-8 input into such a charset.
+	 * NOTE: according to docs ASCII should be used for text packs other
+	 * than disc/track title.
+	 * It might be good in the end to write and pack CD-TEXT pack data 
+	 * ourselves so we can set a different charset from English like 
+	 * Chinese for example. */
 	info = brasero_track_get_audio_info (track);
 
 	strcpy (buffer, "# created by brasero\n");
@@ -457,8 +451,20 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 	if (b_written != size)
 		goto error;
 
-	if (album)
-		string = g_strdup_printf ("Albumtitle=\t%s\n", album);
+	if (album) {
+		gchar *encoded;
+
+		encoded = g_convert_with_fallback (album,
+						   -1,
+						   "ISO-8859-1",
+						   "UTF-8",
+						   "_",	/* Fallback for non convertible characters */
+						   NULL,
+						   NULL,
+						   NULL);
+		string = g_strdup_printf ("Albumtitle=\t%s\n", encoded);
+		g_free (encoded);
+	}
 	else
 		string = strdup ("Albumtitle=\t\n");
 	size = strlen (string);
@@ -467,8 +473,20 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 	if (b_written != size)
 		goto error;
 
-	if (info->artist)
-		string = g_strdup_printf ("Performer=\t%s\n", info->artist);
+	if (info->artist) {
+		gchar *encoded;
+
+		encoded = g_convert_with_fallback (info->artist,
+						   -1,
+						   "ISO-8859-1",
+						   "UTF-8",
+						   "_",	/* Fallback for non convertible characters */
+						   NULL,
+						   NULL,
+						   NULL);
+		string = g_strdup_printf ("Performer=\t%s\n", encoded);
+		g_free (encoded);
+	}
 	else
 		string = strdup ("Performer=\t\n");
 	size = strlen (string);
@@ -477,8 +495,20 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 	if (b_written != size)
 		goto error;
 
-	if (info->composer)
-		string = g_strdup_printf ("Composer=\t%s\n", info->composer);
+	if (info->composer) {
+		gchar *encoded;
+
+		encoded = g_convert_with_fallback (info->composer,
+						   -1,
+						   "ISO-8859-1",
+						   "UTF-8",
+						   "_",	/* Fallback for non convertible characters */
+						   NULL,
+						   NULL,
+						   NULL);
+		string = g_strdup_printf ("Composer=\t%s\n", encoded);
+		g_free (encoded);
+	}
 	else
 		string = strdup ("Composer=\t\n");
 	size = strlen (string);
@@ -487,8 +517,20 @@ brasero_wodim_write_inf (BraseroWodim *wodim,
 	if (b_written != size)
 		goto error;
 
-	if (info->title)
-		string = g_strdup_printf ("Tracktitle=\t%s\n", info->title);
+	if (info->title) {
+		gchar *encoded;
+
+		encoded = g_convert_with_fallback (info->title,
+						   -1,
+						   "ISO-8859-1",
+						   "UTF-8",
+						   "_",	/* Fallback for non convertible characters */
+						   NULL,
+						   NULL,
+						   NULL);
+		string = g_strdup_printf ("Tracktitle=\t%s\n", encoded);
+		g_free (encoded);
+	}
 	else
 		string = strdup ("Tracktitle=\t\n");
 	size = strlen (string);
@@ -583,11 +625,14 @@ error:
 	g_remove (path);
 	g_free (path);
 
+	BRASERO_JOB_LOG (wodim,
+			 "The inf file can't be written : %s",
+			 g_strerror (errsv));
+
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("the inf file can't be written : %s"), 
-		     g_strerror (errsv));
+		     _("An internal error occured"));
 
 	return BRASERO_BURN_ERR;
 }
@@ -694,10 +739,11 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 		/* we need to know what is the type of the track (audio / data) */
 		result = brasero_job_get_input_type (BRASERO_JOB (wodim), &type);
 		if (result != BRASERO_BURN_OK) {
+			BRASERO_JOB_LOG (wodim, "Imager doesn't seem to be ready");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("imager doesn't seem to be ready"));
+				     _("An internal error occured"));
 			return BRASERO_BURN_ERR;
 		}
 		
@@ -706,10 +752,11 @@ brasero_wodim_set_argv_record (BraseroWodim *wodim,
 							      &sectors,
 							      NULL);
 		if (result != BRASERO_BURN_OK) {
+			BRASERO_JOB_LOG (wodim, "The size of the session cannot be retrieved");
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("the size of the session cannot be retrieved"));
+				     _("An internal error occured"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -1041,7 +1088,7 @@ brasero_wodim_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* NOTE: it seems that cdrecord can burn cue files on the fly */
 	brasero_plugin_define (plugin,
 			       "wodim",
-			       _("use wodim to burn CDs"),
+			       _("Use wodim to burn CDs and DVDs"),
 			       "Philippe Rouquier",
 			       0);
 
@@ -1065,6 +1112,15 @@ brasero_wodim_export_caps (BraseroPlugin *plugin, gchar **error)
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (input);
 
+	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_PIPE|
+					BRASERO_PLUGIN_IO_ACCEPT_FILE,
+					BRASERO_AUDIO_FORMAT_RAW|
+					BRASERO_AUDIO_FORMAT_44100|
+					BRASERO_METADATA_INFO);
+
+	brasero_plugin_link_caps (plugin, output, input);
+	g_slist_free (input);
+
 	input = brasero_caps_audio_new (BRASERO_PLUGIN_IO_ACCEPT_PIPE|
 					BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					BRASERO_AUDIO_FORMAT_RAW|
@@ -1188,10 +1244,10 @@ brasero_wodim_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	/* add some configure options */
 	immed = brasero_plugin_conf_option_new (GCONF_KEY_IMMEDIATE_FLAG,
-						_("enable -immed flag (see wodim manual)"),
+						_("Enable \"-immed\" flag (see wodim manual)"),
 						BRASERO_PLUGIN_OPTION_BOOL);
 	minbuf = brasero_plugin_conf_option_new (GCONF_KEY_MINBUF_VALUE,
-						 _("minimum drive buffer fill ratio (in %) (see wodim manual):"),
+						 _("Minimum drive buffer fill ratio (in %) (see wodim manual):"),
 						 BRASERO_PLUGIN_OPTION_INT);
 	brasero_plugin_conf_option_int_set_range (minbuf, 25, 95);
 
